# Usage

This part of the documentation contains various guides and explanations on how to use the different parts of mcproto.

!!! bug "Work In Progress"

    This category is still being written. Many pages are missing.

!!! note "Didn't find what you were looking for?"

    If you were looking for a guide on something, but you didn't find it documented here and you feel like it's
    something that others would benefit from seeing too, you can create a [github issue][issue guide] and ask us to
    write one.

<!--TODO: The gh issue link should probably not point to bug reports, rather to feature requests, we currently don't have a feature requests contributing/community page though. Perhaps it would be better to make it point directly to the github issues page? -->

[issue guide]: ../contributing/issue-guide.md
